from wsknn.fit_transform import fit
from wsknn.predict import predict
from wsknn.model.wsknn import WSKNN
from wsknn.preprocessing.parse_static import parse_files, parse_fn


__version__ = '1.1'
